Gladier: The Globus Architecture for Data-Intensive Experimental Research.
==========================================================================
|docs|

.. |docs| image:: https://readthedocs.org/projects/gladier/badge/?version=latest
   :target: https://gladier.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

Gladier is a programmable data capture, storage, and analysis architecture for experimental facilities.
The architecture leverages a data/computing substrate based on 
data and compute agents deployed across computer and storage 
systems at APS, ALCF, and elsewhere, all managed by cloud-hosted Globus services.

